@@ -12,7 +12,9 @@ import javax.net.ssl.SSLSocket;
 /**
  * Implementation should react to the event when remote SSL peer's certificate is not matching its hostname. 
  * @author K. Benedyczak
+ * @deprecated use {@link HostnameMismatchCallback2} and the related classes
  */
+@Deprecated
 public interface HostnameMismatchCallback
 {
 	/**
